@@ -1,9 +1,6 @@
 #![deny(warnings)]
-use sauron::{
-    html::{attributes::*, *},
-    mt_dom::patch::*,
-    node, *,
-};
+use crate::mt_dom::TreePath;
+use sauron::prelude::*;
 
 #[test]
 fn new_lines_ignored() {
@@ -111,25 +108,22 @@ fn new_lines_ignored() {
     assert_eq!(
         patches,
         vec![
-            ChangeText::new(
-                &Text::new("0"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 0, 0, 0,]),
-                &Text::new("1")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("0"),
+                &leaf::text("1")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 2, 0, 0,]),
-                &Text::new("3")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("3"),
+                &leaf::text("2"),
+                &leaf::text("3")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 3, 0, 0,]),
-                &Text::new("4")
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("3"),
+                &leaf::text("4")
+            ),
+            Patch::insert_node(
                 Some(&"div"),
                 TreePath::new(vec![0, 1, 0, 0, 0,]),
                 &div(
@@ -142,9 +136,8 @@ fn new_lines_ignored() {
                         ),
                     ]
                 )
-            )
-            .into(),
-            InsertNode::new(
+            ),
+            Patch::insert_node(
                 Some(&"div"),
                 TreePath::new(vec![0, 1, 0, 0, 2,]),
                 &div(
@@ -157,16 +150,16 @@ fn new_lines_ignored() {
                         ),
                     ]
                 )
-            )
-            .into(),
-            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1, 0, 0, 1,]),)
-                .into(),
-            ChangeText::new(
-                &Text::new("line: 0, column: 0"),
+            ),
+            Patch::remove_node(
+                Some(&"div"),
+                TreePath::new(vec![0, 1, 0, 0, 1,]),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 1, 0,]),
-                &Text::new("line: 1, column: 0")
-            )
-            .into(),
+                &leaf::text("line: 0, column: 0"),
+                &leaf::text("line: 1, column: 0")
+            ),
         ]
     );
 }
