@@ -1,9 +1,6 @@
 #![deny(warnings)]
-use sauron_core::{
-    html::{attributes::*, *},
-    mt_dom::patch::*,
-    *,
-};
+use crate::mt_dom::TreePath;
+use sauron::prelude::*;
 
 use test_fixtures::simple_program;
 use wasm_bindgen_test::*;
@@ -119,31 +116,27 @@ fn subsequent_updates() {
     assert_eq!(
         patches1,
         vec![
-            ChangeText::new(
-                &Text::new("0"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 0, 0, 0,]),
-                &Text::new("1")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("1"),
+                &leaf::text("0"),
+                &leaf::text("1")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 1, 0, 0,]),
-                &Text::new("2")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("1"),
+                &leaf::text("2")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 2, 0, 0,]),
-                &Text::new("3")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("3"),
+                &leaf::text("2"),
+                &leaf::text("3")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 3, 0, 0,]),
-                &Text::new("4")
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("3"),
+                &leaf::text("4")
+            ),
+            Patch::insert_node(
                 Some(&"section"),
                 TreePath::new(vec![0, 0, 0]),
                 &div(
@@ -154,7 +147,6 @@ fn subsequent_updates() {
                     ],
                 )
             )
-            .into()
         ]
     );
 
@@ -320,37 +312,32 @@ fn subsequent_updates() {
     assert_eq!(
         patches2,
         vec![
-            ChangeText::new(
-                &Text::new("0"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 0, 0, 0,]),
-                &Text::new("1")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("1"),
+                &leaf::text("0"),
+                &leaf::text("1")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 1, 0, 0,]),
-                &Text::new("2")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("1"),
+                &leaf::text("2")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 2, 0, 0,]),
-                &Text::new("3")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("3"),
+                &leaf::text("2"),
+                &leaf::text("3")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 3, 0, 0,]),
-                &Text::new("4")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("4"),
+                &leaf::text("3"),
+                &leaf::text("4")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 4, 0, 0,]),
-                &Text::new("5")
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("4"),
+                &leaf::text("5")
+            ),
+            Patch::insert_node(
                 Some(&"section"),
                 TreePath::new(vec![0, 0, 0,]),
                 &div(
@@ -361,7 +348,6 @@ fn subsequent_updates() {
                     ],
                 )
             )
-            .into()
         ]
     );
 
@@ -471,43 +457,37 @@ fn subsequent_updates() {
     assert_eq!(
         patches3,
         vec![
-            ChangeText::new(
-                &Text::new("0"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 0, 0, 0,]),
-                &Text::new("1")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("1"),
+                &leaf::text("0"),
+                &leaf::text("1")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 1, 0, 0,]),
-                &Text::new("2")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("1"),
+                &leaf::text("2")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 2, 0, 0,]),
-                &Text::new("3")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("3"),
+                &leaf::text("2"),
+                &leaf::text("3")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 3, 0, 0,]),
-                &Text::new("4")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("4"),
+                &leaf::text("3"),
+                &leaf::text("4")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 4, 0, 0,]),
-                &Text::new("5")
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("5"),
+                &leaf::text("4"),
+                &leaf::text("5")
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 0, 5, 0, 0,]),
-                &Text::new("6")
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("5"),
+                &leaf::text("6")
+            ),
+            Patch::insert_node(
                 Some(&"section"),
                 TreePath::new(vec![0, 0, 0,]),
                 &div(
@@ -518,7 +498,6 @@ fn subsequent_updates() {
                     ],
                 )
             )
-            .into()
         ]
     );
 
