@@ -1,10 +1,5 @@
-use sauron_core::{
-    diff,
-    html::{attributes::*, events::*, *},
-    mt_dom::comment,
-    mt_dom::patch::*,
-    Attribute, Node, *,
-};
+use crate::mt_dom::TreePath;
+use sauron::prelude::*;
 
 #[test]
 fn comments_next_to_each_other() {
@@ -19,13 +14,12 @@ fn comments_next_to_each_other() {
     assert_eq!(
         patch,
         vec![
-            ChangeComment::new(
-                &"mordor".to_string(),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1]),
-                &"world".to_string()
-            )
-            .into(),
-            RemoveNode::new(None, TreePath::new(vec![0, 2]),).into()
+                &leaf::comment("mordor".to_string()),
+                &leaf::comment("world".to_string())
+            ),
+            Patch::remove_node(None, TreePath::new(vec![0, 2]),)
         ]
     );
 }
